RangeSelectorLabel class

A label used in SfRangeSelector to customize its value labels.

Inheritance

Constructors

RangeSelectorLabel({required String text, required TextStyle textStyle})
Creates a RangeSelectorLabel with the given text and textStyle.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → String
Contains the text of the slider label.
finalinherited
textStyle → TextStyle
The TextStyle to customize the label text.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited