RangeSliderLabelCreatedCallback typedef

RangeSliderLabelCreatedCallback = RangeSliderLabel Function(dynamic actualValue, String formattedText, TextStyle textStyle)

Signature for customizing the appearance of the label by returning a RangeSliderLabel widget with the provided text and text style.

Implementation

typedef RangeSliderLabelCreatedCallback = RangeSliderLabel Function(
  /// The actual value, which will be either a [DateTime] or [double]
  /// based on given [values].
  dynamic actualValue,

  /// If the actual value is [double], it is formatted by [numberFormat] and
  /// if the actual value is [DateTime], it is formatted by [dateFormat].
  String formattedText,

  /// Customizes the text style of the range slider label.
  TextStyle textStyle,
);