SfDividerShape class

Base class for SfSlider, SfRangeSlider and SfRangeSelector dividers shapes.

Constructors

SfDividerShape()
Enables subclasses to provide constant constructors.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getPreferredSize(SfSliderThemeData themeData, {bool? isActive}) → Size
Returns the size based on the values passed to it.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(PaintingContext context, Offset center, Offset? thumbCenter, Offset? startThumbCenter, Offset? endThumbCenter, {required RenderBox parentBox, required SfSliderThemeData themeData, SfRangeValues? currentValues, dynamic currentValue, required Paint? paint, required Animation<double> enableAnimation, required TextDirection textDirection}) → void
Paints the dividers based on the values passed to it.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited