SfTickShape class

Base class for SfSlider, SfRangeSlider and SfRangeSelector major tick shapes.

Constructors

SfTickShape()
Enables subclasses to provide constant constructors.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getPreferredSize(SfSliderThemeData themeData) → Size
Returns the size based on the values passed to it.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(PaintingContext context, Offset offset, Offset? thumbCenter, Offset? startThumbCenter, Offset? endThumbCenter, {required RenderBox parentBox, required SfSliderThemeData themeData, SfRangeValues? currentValues, dynamic currentValue, required Animation<double> enableAnimation, required TextDirection textDirection}) → void
Paints the major ticks based on the values passed to it.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited