SliderStepDuration class

The class which is used to set step duration for date discrete support.

See also:

  • interval, for setting the interval.
Inheritance

Constructors

SliderStepDuration({int years = 0, int months = 0, int days = 0, int hours = 0, int minutes = 0, int seconds = 0})
The discrete position is calculated by adding the arguments given in the SliderStepDuration object. By default, all arguments values are zero.
const

Properties

days → int
Moves the thumbs based on days.
final
hashCode → int
The hash code for this object.
no setterinherited
hours → int
Moves the thumbs based on hours.
final
minutes → int
Moves the thumbs based on minutes.
final
months → int
Moves the thumbs based on months.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
seconds → int
Moves the thumbs based on seconds.
final
years → int
Moves the thumbs based on years.
final

Methods

debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited